Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(972)

Unified Diff: base/android/base_jni_onload.h

Issue 951673002: Revert "Pull chromium at 2c3ffb2355a27c32f45e508ef861416b820c823b" (Closed) Base URL: git@github.com:domokit/mojo.git@master
Patch Set: Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « base/allocator/BUILD.gn ('k') | base/android/base_jni_onload.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: base/android/base_jni_onload.h
diff --git a/base/android/base_jni_onload.h b/base/android/base_jni_onload.h
index dcc7756684eba733881b84f6891fe41f16d25ad6..f3f05fa54ffcb37d6af6e2a48d2b18469b37b94c 100644
--- a/base/android/base_jni_onload.h
+++ b/base/android/base_jni_onload.h
@@ -9,22 +9,17 @@
#include <vector>
#include "base/base_export.h"
-#include "base/callback.h"
namespace base {
namespace android {
-// Returns whether JNI registration succeeded. Caller shall put the
-// RegisterCallback into |callbacks| in reverse order.
-typedef base::Callback<bool(JNIEnv*)> RegisterCallback;
-BASE_EXPORT bool OnJNIOnLoadRegisterJNI(
- JavaVM* vm,
- std::vector<RegisterCallback> callbacks);
-
-// Returns whether initialization succeeded. Caller shall put the
-// InitCallback into |callbacks| in reverse order.
-typedef base::Callback<bool(void)> InitCallback;
-BASE_EXPORT bool OnJNIOnLoadInit(std::vector<InitCallback> callbacks);
+class JNIOnLoadDelegate;
+
+// Returns whether JNI registration and initialization succeeded. Caller shall
+// put the JNIOnLoadDelegate into |delegates| in reverse order. Refer
+// JNIOnLoadDelegate for more information.
+BASE_EXPORT bool OnJNIOnLoad(JavaVM* vm,
+ std::vector<JNIOnLoadDelegate*>* delegates);
} // namespace android
} // namespace base
« no previous file with comments | « base/allocator/BUILD.gn ('k') | base/android/base_jni_onload.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698